
From: Zachary Amsden <zach@vmware.com>

Move base / limit accessors into desc.h, where they properly belong.

Signed-off-by: Zachary Amsden <zach@vmware.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 include/asm-i386/desc.h   |   34 ++++++++++++++++++++++++++++++++++
 include/asm-i386/system.h |   34 ----------------------------------
 2 files changed, 34 insertions(+), 34 deletions(-)

diff -puN include/asm-i386/desc.h~i386--move-descriptor-accessors-into-desc-h include/asm-i386/desc.h
--- 25/include/asm-i386/desc.h~i386--move-descriptor-accessors-into-desc-h	Wed Aug 17 13:33:56 2005
+++ 25-akpm/include/asm-i386/desc.h	Wed Aug 17 13:33:56 2005
@@ -73,6 +73,40 @@ do { \
 		      : "1" (addr), "r"(desc), "ir"(limit), "i"(type)); \
 } while (0)
 
+#define _set_base(desc,base) do {					\
+	unsigned long __tmp;						\
+	typecheck(struct desc_struct *, desc);				\
+	asm volatile("movw %w5,%2\n\t"					\
+		     "rorl $16,%5\n\t"					\
+		     "movb %b5,%3\n\t"					\
+		     "movb %h5,%4"					\
+		     :"=m"(*(desc)),					\
+		      "=&q" (__tmp)					\
+		     :"m" (*((char *)(desc)+2)),			\
+		      "m" (*((char *)(desc)+4)),			\
+ 		      "m" (*((char *)(desc)+7)),			\
+		      "1" (base));					\
+} while(0)
+
+#define _set_limit(desc,limit) do {					\
+	unsigned long __tmp;						\
+	typecheck(struct desc_struct *, desc);				\
+	asm volatile("movw %w4,%2\n\t"					\
+		     "rorl $16,%4\n\t"					\
+		     "movb %3,%h4\n\t"					\
+		     "andb $0xf0,%h4\n\t"				\
+		     "orb %h4,%b4\n\t"					\
+		     "movb %b4,%3"					\
+		     :"=m"(*(desc)),					\
+		      "=&q" (__tmp)					\
+		     :"m" (*(desc)),					\
+		      "m" (*((char *)(desc)+6)),			\
+		      "1" (limit));					\
+} while(0)
+
+#define set_base(desc,base) _set_base((desc), (base))
+#define set_limit(desc,limit) _set_limit((desc), ((limit)-1)>>12)
+
 #include <mach_desc.h>
 
 #define set_tss_desc(cpu,addr) __set_tss_desc(cpu, GDT_ENTRY_TSS, addr)
diff -puN include/asm-i386/system.h~i386--move-descriptor-accessors-into-desc-h include/asm-i386/system.h
--- 25/include/asm-i386/system.h~i386--move-descriptor-accessors-into-desc-h	Wed Aug 17 13:33:56 2005
+++ 25-akpm/include/asm-i386/system.h	Wed Aug 17 13:33:56 2005
@@ -28,40 +28,6 @@ extern struct task_struct * FASTCALL(__s
 		      "2" (prev), "d" (next));				\
 } while (0)
 
-#define _set_base(desc,base) do {					\
-	unsigned long __tmp;						\
-	typecheck(struct desc_struct *, desc);				\
-	asm volatile("movw %w5,%2\n\t"					\
-		     "rorl $16,%5\n\t"					\
-		     "movb %b5,%3\n\t"					\
-		     "movb %h5,%4"					\
-		     :"=m"(*(desc)),					\
-		      "=&q" (__tmp)					\
-		     :"m" (*((char *)(desc)+2)),			\
-		      "m" (*((char *)(desc)+4)),			\
-		      "m" (*((char *)(desc)+7)),			\
-		      "1" (base));					\
-} while(0)
-
-#define _set_limit(desc,limit) do {					\
-	unsigned long __tmp;						\
-	typecheck(struct desc_struct *, desc);				\
-	asm volatile("movw %w4,%2\n\t"					\
-		     "rorl $16,%4\n\t"					\
-		     "movb %3,%h4\n\t"					\
-		     "andb $0xf0,%h4\n\t"				\
-		     "orb %h4,%b4\n\t"					\
-		     "movb %b4,%3"					\
-		     :"=m"(*(desc)),					\
-		      "=&q" (__tmp)					\
-		     :"m" (*(desc)),					\
-		      "m" (*((char *)(desc)+6)),			\
-		      "1" (limit));					\
-} while(0)
-
-#define set_base(desc,base) _set_base((desc), (base))
-#define set_limit(desc,limit) _set_limit((desc), ((limit)-1)>>12)
-
 /*
  * Load a segment. Fall back on loading the zero
  * segment if something goes wrong..
_
